@@ -51,6 +51,7 @@
 #include <openssl/tls1.h>
 #include <openssl/err.h>
 #include <openssl/evp.h>
+#include <openssl/hmac.h>
 #include "capture.h"
 
 //! Cast two bytes into decimal (Big Endian)
@@ -58,6 +59,12 @@
 //! Cast three bytes into decimal (Big Endian)
 #define UINT24_INT(i) ((i.x[0] << 16) | (i.x[1] << 8) | i.x[2])
 
+//The symbol SSL3_MT_NEWSESSION_TICKET appears to have been introduced at around
+//openssl 0.9.8f, and the use of if breaks builds with older openssls
+#if OPENSSL_VERSION_NUMBER < 0x00908070L
+#define OLD_OPENSSL_VERSION 1
+#endif
+
 //! Three bytes unsigned integer
 typedef struct uint16 {
     unsigned char x[2];
@@ -105,7 +112,9 @@ enum HandshakeType {
     server_hello_done = SSL3_MT_SERVER_DONE,
     certificate_verify = SSL3_MT_CERTIFICATE_VERIFY,
     client_key_exchange = SSL3_MT_CLIENT_KEY_EXCHANGE,
+#ifndef OLD_OPENSSL_VERSION
     new_session_ticket = SSL3_MT_NEWSESSION_TICKET,
+#endif
     finished = SSL3_MT_FINISHED
 };
 
@@ -139,6 +148,15 @@ struct CipherSuite {
     uint8_t cs2;
 };
 
+struct ClientHelloSSLv2 {
+    struct ProtocolVersion client_version;
+    uint16 cipherlist_len;
+    uint16 sessionid_len;
+    uint16 random_len;
+    // CipherSuite cipher_suite;
+    // struct Random random;
+};
+
 //! ClientHello type in Handshake records
 struct ClientHello {
     struct ProtocolVersion client_version;
@@ -344,7 +362,7 @@ tls_connection_dir(struct SSLConnection *conn, struct in_addr addr, uint16_t por
  * @return an existing Connection pointer or NULL if not found
  */
 struct SSLConnection*
-tls_connection_find(struct in_addr addr, uint16_t port);
+tls_connection_find(struct in_addr src, uint16_t sport, struct in_addr dst, uint16_t dport);
 
 /**
  * @brief Process a TCP segment to check TLS data
@@ -378,6 +396,37 @@ int
 tls_process_record(struct SSLConnection *conn, const uint8_t *payload, const int len, uint8_t **out,
                    uint32_t *outl);
 
+/**
+ * @brief Check if this Record looks like SSLv2
+ *
+ * Some devices send the initial ClientHello in a SSLv2 record for compatibility
+ * with only SSLv2 protocol.
+ *
+ * We will only parse SSLv2 Client hello fragments that have TLSv1/SSLv3 content
+ * so this does not make us SSLv2 compatible ;-p
+ * @param conn Existing connection pointer
+ * @param payload Packet peyload
+ * @param len Payload length
+ * @return 1 if payload seems a SSLv2 record, 0 otherwise
+ */
+int
+tls_record_handshake_is_ssl2(struct SSLConnection *conn, const uint8_t *payload,
+                   const int len);
+/**
+ * @brief Process TLS Handshake SSLv2 record types
+ *
+ * Process all types of Handshake records to store and compute all required
+ * data to decrypt application data packets
+ *
+ * @param conn Existing connection pointer
+ * @param fragment Handshake record data
+ * @param len Decimal length of the fragment
+ * @return 0 on valid record processed, 1 otherwise
+ */
+int
+tls_process_record_ssl2(struct SSLConnection *conn, const uint8_t *payload,
+                   const int len, uint8_t **out, uint32_t *outl);
+
 /**
  * @brief Process TLS Handshake record types
  *
