@@ -579,8 +579,12 @@ call_flow_draw_message(ui_t *ui, call_flow_arrow_t *arrow, int cline)
         // Print delta from selected message
         if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
             if (info->selected == -1) {
-                if (setting_enabled(SETTING_CF_DELTA))
-                    timeval_to_delta(msg_get_time(call_group_get_prev_msg(info->group, msg)), msg_get_time(msg), delta);
+                if (setting_enabled(SETTING_CF_DELTA)) {
+                    struct timeval selts, curts;
+                    selts = msg_get_time(call_group_get_prev_msg(info->group, msg));
+                    curts = msg_get_time(msg);
+                    timeval_to_delta(selts, curts, delta);
+                }
             } else if (arrow == vector_item(info->darrows, info->cur_arrow)) {
                 struct timeval selts, curts;
                 selts = msg_get_time(call_flow_arrow_message(call_flow_arrow_selected(ui)));
@@ -1163,6 +1167,9 @@ call_flow_handle_key(ui_t *ui, int key)
                     }
                 }
                 break;
+            case ACTION_CLEAR:
+                info->selected = -1;
+                break;
             case ACTION_CONFIRM:
                 // KEY_ENTER, display current message in raw mode
                 ui_create_panel(PANEL_CALL_RAW);
