@@ -203,7 +203,7 @@ call_list_draw_header(ui_t *ui)
     ui_clear_line(ui, 1);
 
     // Print Open filename in Offline mode
-    if ((infile = capture_input_file()))
+    if (!capture_is_online() && (infile = capture_input_file()))
         mvwprintw(ui->win, 1, 77, "Filename: %s", infile);
 
     mvwprintw(ui->win, 1, 2, "Current Mode: ");
@@ -933,7 +933,7 @@ call_list_help(ui_t *ui)
     mvwprintw(help_win, 17, 2, "F5/Ctrl-L   Clear call list (can not be undone!)");
     mvwprintw(help_win, 18, 2, "F6/R        Show selected call messages in raw mode");
     mvwprintw(help_win, 19, 2, "F7/F        Show filter options");
-    mvwprintw(help_win, 20, 2, "F8/c        Turn on/off window colours");
+    mvwprintw(help_win, 20, 2, "F8/o        Show Settings");
     mvwprintw(help_win, 21, 2, "F10/t       Select displayed columns");
     mvwprintw(help_win, 22, 2, "i/I         Set display filter to invite");
     mvwprintw(help_win, 23, 2, "p           Stop/Resume packet capture");
