@@ -74,7 +74,8 @@ usage()
            "    -q --quiet\t\t Don't print captured dialogs in no interface mode\n"
            "    -D --dump-config\t Print active configuration settings and exit\n"
            "    -f --config\t\t Read configuration from file\n"
-           "    -R --rotate\t\t Rotate calls when capture limit have been reached.\n"
+           "    -F --no-config\t Do not read configuration from default config file\n"
+           "    -R --rotate\t\t Rotate calls when capture limit have been reached\n"
 #ifdef USE_EEP
            "    -H --eep-send\t Homer sipcapture url (udp:X.X.X.X:XXXX)\n"
            "    -L --eep-listen\t Listen for encapsulated packets (udp:X.X.X.X:XXXX)\n"
@@ -130,8 +131,9 @@ main(int argc, char* argv[])
     const char *keyfile;
     const char *match_expr;
     int match_insensitive = 0, match_invert = 0;
-    int no_interface = 0, quiet = 0, rtp_capture = 0, rotate = 0;
+    int no_interface = 0, quiet = 0, rtp_capture = 0, rotate = 0, no_config = 0;
     vector_t *infiles = vector_create(0, 1);
+    vector_t *indevices = vector_create(0, 1);
 
     // Program options
     static struct option long_options[] = {
@@ -145,13 +147,14 @@ main(int argc, char* argv[])
 #endif
         { "calls", no_argument, 0, 'c' },
         { "rtp", no_argument, 0, 'r' },
-        { "limit", no_argument, 0, 'l' },
+        { "limit", required_argument, 0, 'l' },
         { "icase", no_argument, 0, 'i' },
         { "invert", no_argument, 0, 'v' },
         { "no-interface", no_argument, 0, 'N' },
         { "dump-config", no_argument, 0, 'D' },
         { "rotate", no_argument, 0, 'R' },
         { "config", required_argument, 0, 'f' },
+        { "no-config", no_argument, 0, 'F' },
 #ifdef USE_EEP
         { "eep-listen", required_argument, 0, 'L' },
         { "eep-send", required_argument, 0, 'H' },
@@ -159,8 +162,27 @@ main(int argc, char* argv[])
         { "quiet", no_argument, 0, 'q' },
     };
 
+    // Parse command line arguments that have high priority
+    opterr = 0;
+    char *options = "hVd:I:O:pqtW:k:crl:ivNqDL:H:Rf:F";
+    while ((opt = getopt_long(argc, argv, options, long_options, &idx)) != -1) {
+        switch (opt) {
+            case 'h':
+                usage();
+                return 0;
+            case 'V':
+                version();
+                return 0;
+            case 'F':
+                no_config = 1;
+                break;
+            default:
+                break;
+        }
+	}
+
     // Initialize configuration options
-    init_options();
+    init_options(no_config);
 
     // Get initial values for configurable arguments
     device = setting_get_value(SETTING_CAPTURE_DEVICE);
@@ -172,19 +194,17 @@ main(int argc, char* argv[])
     rtp_capture = setting_enabled(SETTING_CAPTURE_RTP);
     rotate = setting_enabled(SETTING_CAPTURE_ROTATE);
 
-    // Parse command line arguments
+    // Parse the rest of command line arguments
     opterr = 0;
-    char *options = "hVd:I:O:pqtW:k:crl:ivNqDL:H:Rf:";
+    optind = 1;  /* reset getopt index */
     while ((opt = getopt_long(argc, argv, options, long_options, &idx)) != -1) {
         switch (opt) {
-            case 'h':
-                usage();
-                return 0;
-            case 'V':
-                version();
-                return 0;
+            case 'h': /* handled before with higher priority options */
+                break;
+            case 'V': /* handled before with higher priority options */
+                break;
             case 'd':
-                device = optarg;
+                vector_append(indevices, optarg);
                 break;
             case 'I':
                 vector_append(infiles, optarg);
@@ -234,6 +254,8 @@ main(int argc, char* argv[])
             case 'f':
                 read_options(optarg);
                 break;
+            case 'F':  /* handled before with higher priority options */
+                break;
             case 'R':
                 rotate = 1;
                 setting_set_value(SETTING_CAPTURE_ROTATE, SETTING_ON);
@@ -301,16 +323,22 @@ main(int argc, char* argv[])
     capture_eep_init();
 #endif
 
+    // If no device or files has been specified in command line, use default
+    if (vector_count(indevices) == 0 && vector_count(infiles) == 0) {
+        vector_append(indevices, (char *) device);
+    }
+
     // If we have an input file, load it
-    if (vector_count(infiles)) {
-        for (i = 0; i < vector_count(infiles); i++) {
-            // Try to load file
-            if (capture_offline(vector_item(infiles, i), outfile) != 0)
-                return 1;
-        }
-    } else {
+    for (i = 0; i < vector_count(infiles); i++) {
+        // Try to load file
+        if (capture_offline(vector_item(infiles, i), outfile) != 0)
+            return 1;
+    }
+
+    // If we have an input device, load it
+    for (i = 0; i < vector_count(indevices); i++) {
         // Check if all capture data is valid
-        if (capture_online(device, outfile) != 0)
+        if (capture_online(vector_item(indevices, i), outfile) != 0)
             return 1;
     }
 
@@ -369,7 +397,7 @@ main(int argc, char* argv[])
         ui_wait_for_input();
     } else {
         setbuf(stdout, NULL);
-        while(capture_status() != CAPTURE_OFFLINE) {
+        while(capture_is_online()) {
             if (!quiet)
                 printf("\rDialog count: %d", sip_calls_count());
             usleep(500 * 1000);
