@@ -47,11 +47,11 @@ option_opt_t options[1024];
 int optscnt = 0;
 
 int
-init_options()
+init_options(int no_config)
 {
     // Custom user conf file
-    char userconf[128];
-    char *home = getenv("HOME");
+    char *userconf = NULL;
+    char *rcfile;
     char pwd[MAX_SETTING_LEN];
 
     // Defualt savepath is current directory
@@ -72,13 +72,23 @@ init_options()
     set_option_value("cl.column6", "dst");
     set_option_value("cl.column7", "state");
 
+	// Done if config file should not be read
+	if(no_config) {
+		return 0;
+	}
+
     // Read options from configuration files
     read_options("/etc/sngreprc");
     read_options("/usr/local/etc/sngreprc");
-    // Get user homedir configuration
-    if (home) {
-        sprintf(userconf, "%s/.sngreprc", home);
-        read_options(userconf);
+    // Get user configuration
+    if ((rcfile = getenv("SNGREPRC"))) {
+        read_options(rcfile);
+    } else if ((rcfile = getenv("HOME"))) {
+        if ((userconf = sng_malloc(strlen(rcfile) + RCFILE_EXTRA_LEN))) {
+            sprintf(userconf, "%s/.sngreprc", rcfile);
+            read_options(userconf);
+            sng_free(userconf);
+        }
     }
 
     return 0;
