@@ -168,15 +168,15 @@ sip_init(int limit, int only_calls, int no_incomplete)
 
     // Initialize payload parsing regexp
     match_flags = REG_EXTENDED | REG_ICASE | REG_NEWLINE;
-    regcomp(&calls.reg_method, "^([a-zA-Z]+) [a-zA-Z]+:[^ ]+ SIP/2.0\r", match_flags & ~REG_NEWLINE);
-    regcomp(&calls.reg_callid, "^(Call-ID|i):[ ]*([^ ]+)\r$", match_flags);
-    regcomp(&calls.reg_xcallid, "^(X-Call-ID|X-CID):[ ]*([^ ]+)\r$", match_flags);
-    regcomp(&calls.reg_response, "^SIP/2.0[ ]*(([0-9]{3}) [^\r]*)\r", match_flags & ~REG_NEWLINE);
+    regcomp(&calls.reg_method, "^([a-zA-Z]+) [a-zA-Z]+:[^ ]+ SIP/2.0[ ]*\r", match_flags & ~REG_NEWLINE);
+    regcomp(&calls.reg_callid, "^(Call-ID|i):[ ]*([^ ]+)[ ]*\r$", match_flags);
+    regcomp(&calls.reg_xcallid, "^(X-Call-ID|X-CID):[ ]*([^ ]+)[ ]*\r$", match_flags);
+    regcomp(&calls.reg_response, "^SIP/2.0[ ]*(([0-9]{3}) [^\r]*)[ ]*\r", match_flags & ~REG_NEWLINE);
     regcomp(&calls.reg_cseq, "^CSeq:[ ]*([0-9]+) .+\r$", match_flags);
-    regcomp(&calls.reg_from, "^(From|f):[ ]*[^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
-    regcomp(&calls.reg_to, "^(To|t):[ ]*[^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
+    regcomp(&calls.reg_from, "^(From|f):[ ]*[^:]*:(([^@>]+)@?[^\r>;]+)", match_flags);
+    regcomp(&calls.reg_to, "^(To|t):[ ]*[^:]*:(([^@>]+)@?[^\r>;]+)", match_flags);
     regcomp(&calls.reg_valid, "^([A-Z]+ [a-zA-Z]+:|SIP/2.0 [0-9]{3})", match_flags & ~REG_NEWLINE);
-    regcomp(&calls.reg_cl, "^(Content-Length|l):[ ]*([0-9]+)\r$", match_flags);
+    regcomp(&calls.reg_cl, "^(Content-Length|l):[ ]*([0-9]+)[ ]*\r$", match_flags);
     regcomp(&calls.reg_body, "\r\n\r\n(.*)", match_flags & ~REG_NEWLINE);
     regcomp(&calls.reg_reason, "Reason:[ ]*[^\r]*;text=\"([^\r]+)\"", match_flags);
     regcomp(&calls.reg_warning, "Warning:[ ]*([0-9]*)", match_flags);
@@ -246,7 +246,7 @@ sip_validate_packet(packet_t *packet)
     int content_len;
     int bodylen;
 
-        // Max SIP payload allowed
+    // Max SIP payload allowed
     if (plen == 0 || plen > MAX_SIP_PAYLOAD)
         return VALIDATE_NOT_SIP;
 
@@ -281,7 +281,19 @@ sip_validate_packet(packet_t *packet)
     // Get the SIP message body length
     bodylen = (int) pmatch[1].rm_eo - pmatch[1].rm_so;
 
-    return (content_len == bodylen) ? VALIDATE_COMPLETE_SIP : VALIDATE_PARTIAL_SIP;
+    // The SDP body of the SIP message ends in another packet
+    if (content_len > bodylen) {
+        return VALIDATE_PARTIAL_SIP;
+    }
+
+    if (content_len < bodylen) {
+        // We got more than one SIP message in the same packet
+        packet_set_payload(packet, payload, pmatch[1].rm_so + content_len);
+        return VALIDATE_MULTIPLE_SIP;
+    }
+
+    // We got all the SDP body of the SIP message
+    return VALIDATE_COMPLETE_SIP;
 }
 
 sip_msg_t *
